@@ -252,6 +252,7 @@ static void gnomecard_take_from_name(GtkWidget *widget, gpointer data)
 	
 extern void gnomecard_edit(GList *node)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "edit" };
 	GnomePropertyBox *box;
 	GnomeCardEditor *ce;
 	GtkWidget *hbox, *hbox2, *vbox, *frame, *table;
@@ -264,7 +265,9 @@ extern void gnomecard_edit(GList *node)
 	Card *crd;
 	time_t tmp_time;
 	gint i;
-	
+
+	help_entry.name = gnome_app_id;
+
 	ce = g_new0(GnomeCardEditor, 1);
 	ce->l = node;
 	crd = (Card *) node->data;
@@ -276,8 +279,8 @@ extern void gnomecard_edit(GList *node)
 	
 	box = GNOME_PROPERTY_BOX(gnome_property_box_new());
 	gtk_object_set_user_data(GTK_OBJECT(box), ce);
-	gtk_window_set_wmclass(GTK_WINDOW(box), "GnomeCard",
-			       "GnomeCard");
+	gtk_window_set_wmclass(GTK_WINDOW(box), "gnomecard",
+			       "gnomecard");
 	gtk_signal_connect(GTK_OBJECT(box), "apply",
 			   (GtkSignalFunc)gnomecard_prop_apply, NULL);
 /*	gtk_signal_connect(GTK_OBJECT(box), "destroy",
@@ -287,6 +290,9 @@ extern void gnomecard_edit(GList *node)
 	gtk_signal_connect(GTK_OBJECT(box), "destroy",
 			   (GtkSignalFunc)gnomecard_prop_close, crd);
 
+	gtk_signal_connect(GTK_OBJECT(box), "help",
+			   GTK_SIGNAL_FUNC (gnome_help_pbox_display),
+			   &help_entry);
 
 	/* Identity notebook page*/
 	vbox = my_gtk_vbox_new();
@@ -635,8 +641,6 @@ gnomecard_setup_apply(GtkWidget *widget, int page)
 	return;             /* ignore partial applies */
     
     
-    gtk_widget_destroy(GTK_WIDGET(gnomecard_list));
-
     edit = (ColumnHdrEditor *) gtk_object_get_user_data(GTK_OBJECT(widget));
     ncol = g_list_length(edit->selHdrs);
 
@@ -658,6 +662,8 @@ gnomecard_setup_apply(GtkWidget *widget, int page)
     if (cols)
 	g_list_free(cols);
 
+    gtk_widget_destroy(GTK_WIDGET(gnomecard_list));
+
     gnomecard_list = GTK_CLIST(gnomecardCreateCardListDisplay(hdrs));
     gtk_container_add(GTK_CONTAINER(cardlist_scrollwin), 
 		      GTK_WIDGET(gnomecard_list));
@@ -872,6 +878,7 @@ colsetup_dnpress(GtkWidget *widget, gpointer data)
 void
 gnomecard_setup(GtkWidget *widget, gpointer data)
 {
+        static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
 	GtkWidget *vbox, *vbox2, *frame;
 	GtkWidget *label, *check;
 
@@ -887,14 +894,20 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 	ColumnHdrEditor  *edit;
 	ColumnHeader     *hdr;
 
+	help_entry.name = gnome_app_id;
+
 	edit = g_new0(ColumnHdrEditor, 1);
 	edit->box = GNOME_PROPERTY_BOX(gnome_property_box_new());
 	gtk_object_set_user_data(GTK_OBJECT(edit->box), edit);
-	gtk_window_set_wmclass(GTK_WINDOW(edit->box), "GnomeCard",
-			       "GnomeCard");
+	gtk_window_set_wmclass(GTK_WINDOW(edit->box), "gnomecard",
+			       "gnomecard");
 	gtk_signal_connect(GTK_OBJECT(edit->box), "apply",
 			   (GtkSignalFunc)gnomecard_setup_apply, NULL);
 
+	gtk_signal_connect(GTK_OBJECT (edit->box), "help",
+			   GTK_SIGNAL_FUNC (gnome_help_pbox_display),
+			   &help_entry);
+
 	vbox = my_gtk_vbox_new();
 	label = gtk_label_new(_("Layout"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(edit->box->notebook),
@@ -1350,25 +1363,12 @@ extern void gnomecard_edit_card(GtkWidget *widget, gpointer data)
 	gnomecard_edit(gnomecard_curr_crd);
 }
 
-static gboolean gnomecard_append_file(char *fname)
+extern gboolean gnomecard_append_file(char *fname)
 {
-	GtkWidget *w;
-	GList *c, *crds;
+	GList *crds;
 
-	if (!(crds = card_load(gnomecard_crds, fname))) {
-		char *tmp;
-		
-		tmp = g_malloc(strlen(_("Wrong file format.")) + strlen(fname) + 3);
-		sprintf(tmp, "%s: %s", fname, _("Wrong file format."));
-		w = gnome_message_box_new(tmp,
-					  GNOME_MESSAGE_BOX_ERROR,
-					  GNOME_STOCK_BUTTON_OK, NULL);
-		GTK_WINDOW(w)->position = GTK_WIN_POS_MOUSE;
-		gtk_widget_show(w);
-		g_free(tmp);
-		
-		return FALSE;
-	}
+	if (!(crds = card_load(gnomecard_crds, fname)))
+	  return FALSE;
 	
 	gnomecard_crds = crds;
 	gnomecard_sort_card_list_by_default();
@@ -1378,14 +1378,32 @@ static gboolean gnomecard_append_file(char *fname)
 	return TRUE;
 }
 
+static void gnomecard_send_read_error(char *fname)
+{
+	GtkWidget *w;
+	char *tmp;
+	
+	tmp = g_malloc(strlen(_("Error reading file.")) + strlen(fname) + 3);
+	sprintf(tmp, "%s: %s", fname, _("Error reading file."));
+	w = gnome_message_box_new(tmp,
+				  GNOME_MESSAGE_BOX_ERROR,
+				  GNOME_STOCK_BUTTON_OK, NULL);
+	GTK_WINDOW(w)->position = GTK_WIN_POS_MOUSE;
+	gtk_widget_show(w);
+	g_free(tmp);
+}
+
 static void gnomecard_append_call(GtkWidget *widget, gpointer data)
 {
 	char *fname;
 	
 	fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(widget));
 	
-	if (gnomecard_append_file(fname))
-		gtk_widget_destroy(widget);
+	if (gnomecard_append_file(fname)) {
+			gnomecard_set_changed(TRUE);
+			gtk_widget_destroy(widget);
+	} else
+	  gnomecard_send_read_error(fname);
 }
 
 extern void gnomecard_append(GtkWidget *widget, gpointer data)
@@ -1408,7 +1426,11 @@ extern gboolean gnomecard_open_file(char *fname)
 	if (! gnomecard_destroy_cards())
 	  return FALSE;
 	
-	return gnomecard_append_file(fname);
+	if (gnomecard_append_file(fname))
+	  return TRUE;
+	
+	gnomecard_send_read_error(fname);
+	return FALSE;
 }
 
 static void gnomecard_open_call(GtkWidget *widget, gpointer data)
@@ -1471,7 +1493,7 @@ extern void gnomecard_about(GtkWidget *widget, gpointer data)
 				   "drmike@redhat.com",
 				   NULL };
 	
-	about = gnome_about_new (_("GnomeCard"), NULL,
+	about = gnome_about_new (_("gnomecard"), NULL,
 				 "(C) 1997-1998 the Free Software Fundation",
 				 authors,
 				 _("Electronic Business Card Manager"),
