@@ -358,13 +358,13 @@ void gnomecard_spawn_new(GtkWidget *widget, gpointer data)
 {
 	GtkWidget *w;
 	int pid;
-	char *text[] = { "GnomeCard", NULL };
+	char *text[] = { "gnomecard", NULL };
 	
 	pid = fork();
 	if (pid == 0) { /* child */
 /* gnomecard: error in loading shared libraries
  * /gnome/lib/libgnome.so.0: undefined symbol: stat */
-		if (execvp("GnomeCard", text) == -1) { 
+		if (execvp("gnomecard", text) == -1) { 
 			w = gnome_message_box_new(_("A new Gnomecard could not be spawned. Maybe it is not in your path."),
 																GNOME_MESSAGE_BOX_ERROR,
 																GNOME_STOCK_BUTTON_OK, NULL);
@@ -386,7 +386,7 @@ GnomeUIInfo filemenu[] = {
 
 	GNOMEUIINFO_MENU_SAVE_AS_ITEM(gnomecard_save_as, NULL),
 
-	{GNOME_APP_UI_ITEM, N_("_Merge with..."),
+	{GNOME_APP_UI_ITEM, N_("_Append..."),
 	 N_("Add the contents of another Card File."),
 	 gnomecard_append, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 0, 0, NULL},
@@ -514,14 +514,14 @@ GnomeUIInfo viewmenu[] = {
 };
 
 GnomeUIInfo settingsmenu[] = {
-        GNOMEUIINFO_MENU_PREFERENCES_ITEM(gnomecard_setup, NULL),
-	GNOMEUIINFO_END
+		GNOMEUIINFO_MENU_PREFERENCES_ITEM(gnomecard_setup, NULL),
+		GNOMEUIINFO_END
 };
 
 GnomeUIInfo helpmenu[] = {
-        GNOMEUIINFO_HELP("gnomecard"),
-	GNOMEUIINFO_MENU_ABOUT_ITEM(gnomecard_about, NULL),
-	GNOMEUIINFO_END
+		GNOMEUIINFO_HELP("gnomecard"),
+		GNOMEUIINFO_MENU_ABOUT_ITEM(gnomecard_about, NULL),
+		GNOMEUIINFO_END
 };
 
 GnomeUIInfo mainmenu[] = {
@@ -543,10 +543,6 @@ GnomeUIInfo mainmenu[] = {
 };
 
 GnomeUIInfo toolbar[] = {
-	{GNOME_APP_UI_ITEM, N_("New"), N_("New file"), 
-		gnomecard_destroy_cards, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_NEW, 0, 0, NULL},
-
 	{GNOME_APP_UI_ITEM, N_("Open"), N_("Open file"), 
 		gnomecard_open, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_OPEN, 0, 0, NULL},
@@ -618,16 +614,16 @@ void gnomecard_init(void)
 	gnomecard_init_stock();
 	gnomecard_init_pixes();
 	
-	gnomecard_window = GNOME_APP(gnome_app_new("GnomeCard", "GnomeCard"));
+	gnomecard_window = GNOME_APP(gnome_app_new("gnomecard", "gnomecard"));
 
-	appbar = GNOME_APPBAR(gnome_appbar_new(TRUE, TRUE,
+	appbar = GNOME_APPBAR(gnome_appbar_new(FALSE, TRUE,
 					       GNOME_PREFERENCES_USER));
 	gnome_app_set_statusbar(GNOME_APP(gnomecard_window),
 				GTK_WIDGET(appbar));
 
 #if 0
-	gtk_window_set_wmclass(GTK_WINDOW(gnomecard_window), "GnomeCard",
-			       "GnomeCard");
+	gtk_window_set_wmclass(GTK_WINDOW(gnomecard_window), "gnomecard",
+			       "gnomecard");
 	gtk_window_set_policy(GTK_WINDOW(gnomecard_window), TRUE, TRUE, TRUE);
 #endif
 			      
@@ -650,7 +646,7 @@ void gnomecard_init(void)
 	/* card display layout */
 	ncol=gnome_config_get_int("/GnomeCard/CardDisplay/ncols=0");
 	if (!ncol) {
-	    gnomecard_list = gnomecardCreateCardListDisplay(defaulthdrs);
+	    gnomecard_list = GTK_CLIST(gnomecardCreateCardListDisplay(defaulthdrs));
 	} else {
 	    hdrs = g_new0(ColumnType, ncol+1);
 	    for (p=hdrs, i=0; i<ncol; i++) {
@@ -667,10 +663,10 @@ void gnomecard_init(void)
 		}
 	    }
 	    *p = COLTYPE_END;
-	    gnomecard_list = gnomecardCreateCardListDisplay(hdrs);
+	    gnomecard_list = GTK_CLIST(gnomecardCreateCardListDisplay(hdrs));
 	}
 
-	gtk_container_add(GTK_CONTAINER(cardlist_scrollwin), gnomecard_list);
+	gtk_container_add(GTK_CONTAINER(cardlist_scrollwin), GTK_WIDGET(gnomecard_list));
 	gtk_signal_connect(GTK_OBJECT(cardlist_scrollwin),
 			  "button_press_event",
 			  GTK_SIGNAL_FUNC(list_button_press),
@@ -716,16 +712,16 @@ void gnomecard_init(void)
 
 	/* FIXME ? - ugly mechanism to be able to enable/disable buttons on */
 	/*           toolbar                                                */
-	tb_save = toolbar[2].widget;
-	tb_edit = toolbar[5].widget;
-	tb_del  = toolbar[6].widget;
-	tb_first = toolbar[8].widget;
-	tb_prev = toolbar[9].widget;
-	tb_next = toolbar[10].widget;
-	tb_last = toolbar[11].widget;
-	tb_find = toolbar[13].widget;
+	tb_save = toolbar[1].widget;
+	tb_edit = toolbar[4].widget;
+	tb_del  = toolbar[5].widget;
+	tb_first = toolbar[7].widget;
+	tb_prev = toolbar[8].widget;
+	tb_next = toolbar[9].widget;
+	tb_last = toolbar[10].widget;
+	tb_find = toolbar[12].widget;
 	
-	menu_save = filemenu[5].widget;
+	menu_save = filemenu[2].widget;
 	menu_edit = editmenu[0].widget;
 	menu_del  = editmenu[1].widget;
 	menu_find = editmenu[5].widget;
@@ -739,10 +735,8 @@ void gnomecard_init(void)
 	gnomecard_init_defaults();
 	gnomecard_set_changed(FALSE);
 	
-	if (*gnomecard_fname)
-		gnomecard_open_file(gnomecard_fname);
-	else
-		gnomecard_set_curr(NULL);
+	if (! gnomecard_append_file(gnomecard_fname))
+	  gnomecard_set_curr(NULL);
 
 	gtk_widget_show(GTK_WIDGET (gnomecard_window));
 
@@ -760,7 +754,7 @@ int main (int argc, char *argv[])
 	textdomain(PACKAGE);
 
 	CORBA_exception_init(&ev);
-	orb = gnome_CORBA_init("GnomeCard", VERSION, &argc, argv, GNORBA_INIT_SERVER_FUNC, &ev);
+	orb = gnome_CORBA_init("gnomecard", VERSION, &argc, argv, GNORBA_INIT_SERVER_FUNC, &ev);
 	Exception (&ev);
 
 	poa = CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
